quantizationtools.PitchedQEvent
===============================

.. abjad-lineage:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent

.. autoclass:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.attachments
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.index
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.offset
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.pitches
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__getstate__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__repr__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent.PitchedQEvent.__setstate__
   :noindex:
